@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_INI_USR_OBJ_PORTS_PHP_7_2_10_PHP_7_2_10_ZEND_ZEND_INI_PARSER_H_INCLUDED
-# define YY_INI_USR_OBJ_PORTS_PHP_7_2_10_PHP_7_2_10_ZEND_ZEND_INI_PARSER_H_INCLUDED
+#ifndef YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
+# define YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -62,22 +62,6 @@ extern int ini_debug;
     END_OF_LINE = 272
   };
 #endif
-/* Tokens.  */
-#define TC_SECTION 258
-#define TC_RAW 259
-#define TC_CONSTANT 260
-#define TC_NUMBER 261
-#define TC_STRING 262
-#define TC_WHITESPACE 263
-#define TC_LABEL 264
-#define TC_OFFSET 265
-#define TC_DOLLAR_CURLY 266
-#define TC_VARNAME 267
-#define TC_QUOTED_STRING 268
-#define BOOL_TRUE 269
-#define BOOL_FALSE 270
-#define NULL_NULL 271
-#define END_OF_LINE 272
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -90,4 +74,4 @@ typedef int YYSTYPE;
 
 int ini_parse (void);
 
-#endif /* !YY_INI_USR_OBJ_PORTS_PHP_7_2_10_PHP_7_2_10_ZEND_ZEND_INI_PARSER_H_INCLUDED  */
+#endif /* !YY_INI_ZEND_ZEND_INI_PARSER_H_INCLUDED  */
